Calculate the number of combinations that can be derived from the given character vector.
Examples
how_many_subsets(c("qqa", "bnk", "sdf", "123"))
#> [1] 15
Calculate the number of combinations that can be derived from the given character vector.
how_many_subsets(c("qqa", "bnk", "sdf", "123"))
#> [1] 15